package Net::Async::Trello::Organisation;
$Net::Async::Trello::Organisation::VERSION = '0.001';
use strict;
use warnings;

use parent qw(Net::Async::Trello::Generated::Organisation);

=head1 NAME

Net::Async::Trello::Organisation

=head1 VERSION

version 0.001

=head1 DESCRIPTION

Autogenerated module.

=cut

1;
