package Net::Async::Trello::CardAction;
$Net::Async::Trello::CardAction::VERSION = '0.001';
use strict;
use warnings;

use parent qw(Net::Async::Trello::Generated::CardAction);

=head1 NAME

Net::Async::Trello::CardAction

=head1 VERSION

version 0.001

=head1 DESCRIPTION

Autogenerated module.

=cut

1;
