package Net::Async::Trello::Generated::Board;
$Net::Async::Trello::Generated::Board::VERSION = '0.001';
use strict;
use warnings;

use parent qw(Net::Async::Trello::Common);

=head1 NAME

Net::Async::Trello::Generated::Board

=head1 VERSION

version 0.001

=head1 DESCRIPTION

Autogenerated module.

=cut

use URI ();

=head1 METHODS

=cut

=head2 id

Provides an accessor for C<id>.

=cut

sub id { shift->{id} }

=head2 closed

Provides an accessor for C<closed>.

=cut

sub closed { shift->{closed} }

=head2 date_last_activity

Provides an accessor for C<dateLastActivity>.

=cut

sub date_last_activity { shift->{dateLastActivity} }

=head2 date_last_view

Provides an accessor for C<dateLastView>.

=cut

sub date_last_view { shift->{dateLastView} }

=head2 desc

Provides an accessor for C<desc>.

=cut

sub desc { shift->{desc} }

=head2 desc_data

Provides an accessor for C<descData>.

=cut

sub desc_data { shift->{descData} }

=head2 id_organization

Provides an accessor for C<idOrganization>.

=cut

sub id_organization { shift->{idOrganization} }

=head2 invitations

Provides an accessor for C<invitations>.

=cut

sub invitations { shift->{invitations} }

=head2 invited

Provides an accessor for C<invited>.

=cut

sub invited { shift->{invited} }

=head2 label_names

Provides an accessor for C<labelNames>.

=cut

sub label_names { shift->{labelNames} }

=head2 memberships

Provides an accessor for C<memberships>.

=cut

sub memberships { shift->{memberships} }

=head2 name

Provides an accessor for C<name>.

=cut

sub name { shift->{name} }

=head2 pinned

Provides an accessor for C<pinned>.

=cut

sub pinned { shift->{pinned} }

=head2 power_ups

Provides an accessor for C<powerUps>.

=cut

sub power_ups { shift->{powerUps} }

=head2 prefs

Provides an accessor for C<prefs>.

=cut

sub prefs { shift->{prefs} }

=head2 short_link

Provides an accessor for C<shortLink>.

=cut

sub short_link { shift->{shortLink} }

=head2 short_url

Provides an accessor for C<shortUrl>.

=cut

sub short_url { shift->{shortUrl} }

=head2 starred

Provides an accessor for C<starred>.

=cut

sub starred { shift->{starred} }

=head2 subscribed

Provides an accessor for C<subscribed>.

=cut

sub subscribed { shift->{subscribed} }

=head2 url

Provides an accessor for C<url>.

=cut

sub url { shift->{url} }

1;
